<?php

namespace Drupal\layout_builder_base;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\layout_builder_base\Form\SettingsForm;

/**
 * Class ConfigManagerService.
 */
class ConfigManagerService implements ConfigManagerServiceInterface {

  /**
   * Drupal\Core\Config\ConfigFactoryInterface definition.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The layout builder base settings.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $layoutBuilderBaseSettings;

  /**
   * Constructs a new ConfigManagerService object.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
    $this->layoutBuilderBaseSettings = $config_factory->get('layout_builder_base.settings');
  }

  public function getOverrideOptionsFromPropertyName($property) {
    $options = [];
    $config_name = SettingsForm::getOverrideConfigName($property);
    $config_value = $this->layoutBuilderBaseSettings->get($config_name);
    if (!empty($config_value)) {
      $options_values = explode(PHP_EOL, $config_value);
      foreach ($options_values as $option_value) {
        $data = explode('|', $option_value);
        if (count($data) === 2) {
          $options[trim($data[0])] = trim($data[0]);
        }
      }
    }

    return $options;
  }

}
